@@ -1,8 +1,9 @@
-from django.core.management.base import no_translations, CommandError
+from django.core.management.base import CommandError
 from django.core.management.commands.migrate import Command as MigrateCommand
 from django.db import connections
 
-from isapilib.connection import add_conn
+from isapilib.Connection import create_conn
+from isapilib.models import SepaBranch
 
 
 class Command(MigrateCommand):
@@ -11,20 +12,17 @@ class Command(MigrateCommand):
 
     def add_arguments(self, parser):
         parser.add_argument(
-            "username",
+            "branch",
             nargs="?",
-            help="username",
-        )
-        parser.add_argument(
-            "organization_id",
-            nargs="?",
-            help="organization_id",
+            help="id branch",
         )
         super().add_arguments(parser)
 
-    @no_translations
     def handle(self, *args, **options):
-        options['database'] = add_conn(options['username'], options['organization_id'])
+        branch = SepaBranch.objects.get(id=options["branch"])
+        connections.databases['external'] = create_conn(branch)
+        options['database'] = 'external'
+
         if not options['app_label']:
             raise CommandError('you must specified app_name')
         elif options['app_label'] in self.exclude_apps:
